This should now refer to xPL rather than SPL, so update it throughout
the tree.

Signed-off-by: Simon Glass <s...@chromium.org>
---

Changes in v3:
- Move to earlier in the series

 arch/arm/lib/cache.c     |  2 +-
 doc/develop/logging.rst  |  2 +-
 drivers/spi/spi-uclass.c |  4 ++--
 include/log.h            | 12 ++++++------
 4 files changed, 10 insertions(+), 10 deletions(-)

diff --git a/arch/arm/lib/cache.c b/arch/arm/lib/cache.c
index b2ae74a59f1..cac2159fe1a 100644
--- a/arch/arm/lib/cache.c
+++ b/arch/arm/lib/cache.c
@@ -62,7 +62,7 @@ int check_cache_range(unsigned long start, unsigned long stop)
                ok = 0;
 
        if (!ok) {
-               warn_non_spl("CACHE: Misaligned operation at range [%08lx, 
%08lx]\n",
+               warn_non_xpl("CACHE: Misaligned operation at range [%08lx, 
%08lx]\n",
                             start, stop);
        }
 
diff --git a/doc/develop/logging.rst b/doc/develop/logging.rst
index 704a6bf1d84..d7a40c94bf0 100644
--- a/doc/develop/logging.rst
+++ b/doc/develop/logging.rst
@@ -292,7 +292,7 @@ Convert debug() statements in the code to log() statements
 
 Convert error() statements in the code to log() statements
 
-Figure out what to do with BUG(), BUG_ON() and warn_non_spl()
+Figure out what to do with BUG(), BUG_ON() and warn_non_xpl()
 
 Add a way to browse log records
 
diff --git a/drivers/spi/spi-uclass.c b/drivers/spi/spi-uclass.c
index 6e281725239..f6efebd2e90 100644
--- a/drivers/spi/spi-uclass.c
+++ b/drivers/spi/spi-uclass.c
@@ -538,7 +538,7 @@ int spi_slave_of_to_plat(struct udevice *dev, struct 
dm_spi_slave_plat *plat)
                mode |= SPI_TX_OCTAL;
                break;
        default:
-               warn_non_spl("spi-tx-bus-width %d not supported\n", value);
+               warn_non_xpl("spi-tx-bus-width %d not supported\n", value);
                break;
        }
 
@@ -556,7 +556,7 @@ int spi_slave_of_to_plat(struct udevice *dev, struct 
dm_spi_slave_plat *plat)
                mode |= SPI_RX_OCTAL;
                break;
        default:
-               warn_non_spl("spi-rx-bus-width %d not supported\n", value);
+               warn_non_xpl("spi-rx-bus-width %d not supported\n", value);
                break;
        }
 
diff --git a/include/log.h b/include/log.h
index 7c25bf0b081..bf81a27011f 100644
--- a/include/log.h
+++ b/include/log.h
@@ -246,10 +246,10 @@ int _log_buffer(enum log_category_t cat, enum log_level_t 
level,
 #define _DEBUG 0
 #endif
 
-#ifdef CONFIG_SPL_BUILD
-#define _SPL_BUILD     1
+#ifdef CONFIG_XPL_BUILD
+#define _XPL_BUILD     1
 #else
-#define _SPL_BUILD     0
+#define _XPL_BUILD     0
 #endif
 
 #if CONFIG_IS_ENABLED(LOG)
@@ -281,9 +281,9 @@ int _log_buffer(enum log_category_t cat, enum log_level_t 
level,
 #define debug(fmt, args...)                    \
        debug_cond(_DEBUG, fmt, ##args)
 
-/* Show a message if not in SPL */
-#define warn_non_spl(fmt, args...)                     \
-       debug_cond(!_SPL_BUILD, fmt, ##args)
+/* Show a message if not in xPL */
+#define warn_non_xpl(fmt, args...)                     \
+       debug_cond(!_XPL_BUILD, fmt, ##args)
 
 /*
  * An assertion is run-time check done in debug mode only. If DEBUG is not
-- 
2.34.1

Reply via email to